/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.cropcircle;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.beans.PropertyChangeListener;
import java.beans.PropertyEditor;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import org.openide.util.NbBundle;

/**
 * Custom property editor for time values notated as HHmmss.SS or HHmmss
 * Will return a date of first of January 1970 with a time set to the parsed value.  
 * @author Merijn Zengers
 */
public class UtcTimePropertyEditor implements PropertyEditor {

    private static final SimpleDateFormat TIME_FORMAT_MILIS = new SimpleDateFormat("HHmmss.SS");
    private static final SimpleDateFormat TIME_FORMAT = new SimpleDateFormat("HHmmss");
    private Date utcTime;
    private static final AppLogger LOG = AppLogFactory.getLogger(UtcTimePropertyEditor.class);

    @Override
    public void setValue(Object value) {
        setAsText(value.toString());
    }

    @Override
    public Object getValue() {
        return utcTime;
    }

    @Override
    public boolean isPaintable() {
        return false;
    }

    @Override
    public void paintValue(Graphics gfx, Rectangle box) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public String getJavaInitializationString() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public String getAsText() {
        return utcTime.toString();
    }

    @Override
    public void setAsText(String text) throws IllegalArgumentException {
        try {
            if (text.contains(".") && text.length() == 9) {
                this.utcTime = TIME_FORMAT_MILIS.parse(text);
            } else {
                this.utcTime = TIME_FORMAT.parse(text);
            }
        } catch (ParseException ex) {
            LOG.error(NbBundle.getMessage(UtcTimePropertyEditor.class, "sensor.cropcircle.fileprocessor.logerror.failed_to_create_time", text), ex);
            throw (new RuntimeException(ex));
        }
    }

    @Override
    public String[] getTags() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public Component getCustomEditor() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public boolean supportsCustomEditor() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        throw new UnsupportedOperationException("Not supported yet.");
    }
}
